You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@ignite.apache.org by sk...@apache.org on 2022/08/09 10:20:21 UTC

[ignite-3] branch main updated: IGNITE-17233 Clarify cluster URL parameter name. Fixes #974

This is an automated email from the ASF dual-hosted git repository.

sk0x50 pushed a commit to branch main
in repository https://gitbox.apache.org/repos/asf/ignite-3.git


The following commit(s) were added to refs/heads/main by this push:
     new 10e977eb6 IGNITE-17233 Clarify cluster URL parameter name. Fixes #974
10e977eb6 is described below

commit 10e977eb67aa5a702afce9b864b383c6d2660cd6
Author: Vadim Pakhnushev <86...@users.noreply.github.com>
AuthorDate: Tue Aug 9 13:20:06 2022 +0300

    IGNITE-17233 Clarify cluster URL parameter name. Fixes #974
    
    Signed-off-by: Slava Koptilin <sl...@gmail.com>
---
 .../ItClusterStatusReplCommandInitializedTest.java |  2 +-
 ...ClusterStatusReplCommandNotInitializedTest.java |  2 +-
 .../ItTopologyCommandInitializedClusterTest.java   |  4 +-
 ...ItTopologyCommandNotInitializedClusterTest.java |  4 +-
 .../configuration/ItConfigCommandTest.java         | 16 +++----
 .../cli/deprecated/ItClusterCommandTest.java       |  2 +-
 .../ignite/cli/commands/OptionsConstants.java      | 50 ++++++++++++++++++++++
 .../config/ClusterConfigShowReplSubCommand.java    |  8 +++-
 .../config/ClusterConfigShowSubCommand.java        |  8 +++-
 .../config/ClusterConfigUpdateReplSubCommand.java  |  8 +++-
 .../config/ClusterConfigUpdateSubCommand.java      |  8 +++-
 .../cluster/init/ClusterInitReplSubCommand.java    | 12 ++++--
 .../cluster/init/ClusterInitSubCommand.java        | 10 +++--
 .../status/ClusterStatusReplSubCommand.java        | 11 +++--
 .../cluster/status/ClusterStatusSubCommand.java    |  8 +++-
 .../node/config/NodeConfigShowReplSubCommand.java  | 10 +++--
 .../node/config/NodeConfigShowSubCommand.java      |  8 +++-
 .../config/NodeConfigUpdateReplSubCommand.java     |  8 +++-
 .../node/config/NodeConfigUpdateSubCommand.java    |  8 +++-
 .../node/status/NodeStatusReplSubCommand.java      | 13 +++---
 .../commands/node/status/NodeStatusSubCommand.java |  8 +++-
 .../questions/ConnectToClusterQuestion.java        |  3 +-
 .../topology/LogicalTopologyReplSubCommand.java    | 11 +++--
 .../topology/LogicalTopologySubCommand.java        |  8 +++-
 .../topology/PhysicalTopologyReplSubCommand.java   | 11 +++--
 .../topology/PhysicalTopologySubCommand.java       |  8 +++-
 .../apache/ignite/cli/config/ConfigConstants.java  |  2 +-
 .../repl/completer/DynamicCompleterFilter.java     |  5 ++-
 .../cli/core/repl/completer/NodeUrlProvider.java   |  6 ++-
 .../cli/commands/UrlOptionsNegativeTest.java       | 24 +++++------
 .../cliconfig/CliConfigGetSubCommandTest.java      |  2 +-
 .../cliconfig/CliConfigSetSubCommandTest.java      | 10 ++---
 .../cli/commands/cliconfig/ConfigManagerTest.java  |  4 +-
 .../repl/completer/DynamicCompleterFilterTest.java | 16 +++----
 .../repl/completer/HoconDynamicCompleterTest.java  |  8 ++--
 .../cli/deprecated/IgniteCliInterfaceTest.java     | 31 +++++++-------
 .../cli/src/test/resources/integration_tests.ini   |  2 +-
 37 files changed, 244 insertions(+), 115 deletions(-)

diff --git a/modules/cli/src/integrationTest/java/org/apache/ignite/cli/commands/cluster/status/ItClusterStatusReplCommandInitializedTest.java b/modules/cli/src/integrationTest/java/org/apache/ignite/cli/commands/cluster/status/ItClusterStatusReplCommandInitializedTest.java
index 3891d663a..ccba62994 100644
--- a/modules/cli/src/integrationTest/java/org/apache/ignite/cli/commands/cluster/status/ItClusterStatusReplCommandInitializedTest.java
+++ b/modules/cli/src/integrationTest/java/org/apache/ignite/cli/commands/cluster/status/ItClusterStatusReplCommandInitializedTest.java
@@ -40,7 +40,7 @@ class ItClusterStatusReplCommandInitializedTest extends CliCommandTestInitialize
     @Test
     @DisplayName("Should print status when valid cluster url is given but cluster is initialized")
     void printStatus() {
-        execute("cluster", "status", "--cluster-url", NODE_URL);
+        execute("cluster", "status", "--cluster-endpoint-url", NODE_URL);
 
         assertAll(
                 this::assertExitCodeIsZero,
diff --git a/modules/cli/src/integrationTest/java/org/apache/ignite/cli/commands/cluster/status/ItClusterStatusReplCommandNotInitializedTest.java b/modules/cli/src/integrationTest/java/org/apache/ignite/cli/commands/cluster/status/ItClusterStatusReplCommandNotInitializedTest.java
index c1f4ab7f0..229ba2db5 100644
--- a/modules/cli/src/integrationTest/java/org/apache/ignite/cli/commands/cluster/status/ItClusterStatusReplCommandNotInitializedTest.java
+++ b/modules/cli/src/integrationTest/java/org/apache/ignite/cli/commands/cluster/status/ItClusterStatusReplCommandNotInitializedTest.java
@@ -31,7 +31,7 @@ class ItClusterStatusReplCommandNotInitializedTest extends CliCommandTestNotInit
     @Test
     @DisplayName("Should print status when valid cluster url is given but cluster is not initialized")
     void printStatus() {
-        execute("cluster", "status", "--cluster-url", NODE_URL);
+        execute("cluster", "status", "--cluster-endpoint-url", NODE_URL);
 
         assertAll(
                 this::assertExitCodeIsZero,
diff --git a/modules/cli/src/integrationTest/java/org/apache/ignite/cli/commands/cluster/topology/ItTopologyCommandInitializedClusterTest.java b/modules/cli/src/integrationTest/java/org/apache/ignite/cli/commands/cluster/topology/ItTopologyCommandInitializedClusterTest.java
index c7c556b8e..e4c155f03 100644
--- a/modules/cli/src/integrationTest/java/org/apache/ignite/cli/commands/cluster/topology/ItTopologyCommandInitializedClusterTest.java
+++ b/modules/cli/src/integrationTest/java/org/apache/ignite/cli/commands/cluster/topology/ItTopologyCommandInitializedClusterTest.java
@@ -33,7 +33,7 @@ class ItTopologyCommandInitializedClusterTest extends CliCommandTestInitializedI
     @DisplayName("Should print physical topology when valid cluster url is provided")
     void printPhysicalTopology() {
         // When
-        execute("cluster", "topology", "physical", "--cluster-url", NODE_URL);
+        execute("cluster", "topology", "physical", "--cluster-endpoint-url", NODE_URL);
 
         // Then
         assertAll(
@@ -47,7 +47,7 @@ class ItTopologyCommandInitializedClusterTest extends CliCommandTestInitializedI
     @DisplayName("Should print logical topology when valid cluster url is provided but cluster")
     void printLogicalTopology() {
         // When
-        execute("cluster", "topology", "logical", "--cluster-url", NODE_URL);
+        execute("cluster", "topology", "logical", "--cluster-endpoint-url", NODE_URL);
 
         // Then
         assertAll(
diff --git a/modules/cli/src/integrationTest/java/org/apache/ignite/cli/commands/cluster/topology/ItTopologyCommandNotInitializedClusterTest.java b/modules/cli/src/integrationTest/java/org/apache/ignite/cli/commands/cluster/topology/ItTopologyCommandNotInitializedClusterTest.java
index 0c660969c..cb8afd4eb 100644
--- a/modules/cli/src/integrationTest/java/org/apache/ignite/cli/commands/cluster/topology/ItTopologyCommandNotInitializedClusterTest.java
+++ b/modules/cli/src/integrationTest/java/org/apache/ignite/cli/commands/cluster/topology/ItTopologyCommandNotInitializedClusterTest.java
@@ -33,7 +33,7 @@ class ItTopologyCommandNotInitializedClusterTest extends CliCommandTestNotInitia
     @DisplayName("Should print physical topology when valid cluster url is provided")
     void printPhysicalTopology() {
         // When
-        execute("cluster", "topology", "physical", "--cluster-url", NODE_URL);
+        execute("cluster", "topology", "physical", "--cluster-endpoint-url", NODE_URL);
 
         // Then
         assertAll(
@@ -47,7 +47,7 @@ class ItTopologyCommandNotInitializedClusterTest extends CliCommandTestNotInitia
     @DisplayName("Should not print logical topology when valid cluster url is provided but cluster is not initialized")
     void printLogicalTopology() {
         // When
-        execute("cluster", "topology", "logical", "--cluster-url", NODE_URL);
+        execute("cluster", "topology", "logical", "--cluster-endpoint-url", NODE_URL);
 
         // Then prints nothing
         assertAll(
diff --git a/modules/cli/src/integrationTest/java/org/apache/ignite/cli/commands/configuration/ItConfigCommandTest.java b/modules/cli/src/integrationTest/java/org/apache/ignite/cli/commands/configuration/ItConfigCommandTest.java
index f596b5973..9a1be43af 100644
--- a/modules/cli/src/integrationTest/java/org/apache/ignite/cli/commands/configuration/ItConfigCommandTest.java
+++ b/modules/cli/src/integrationTest/java/org/apache/ignite/cli/commands/configuration/ItConfigCommandTest.java
@@ -30,10 +30,10 @@ import org.junit.jupiter.api.Test;
 class ItConfigCommandTest extends CliCommandTestInitializedIntegrationBase {
 
     @Test
-    @DisplayName("Should read config when valid cluster-url is given")
+    @DisplayName("Should read config when valid cluster-endpoint-url is given")
     void readDefaultConfig() {
         // When read cluster config with valid url
-        execute("cluster", "config", "show", "--cluster-url", NODE_URL);
+        execute("cluster", "config", "show", "--cluster-endpoint-url", NODE_URL);
 
         // Then
         assertAll(
@@ -44,10 +44,10 @@ class ItConfigCommandTest extends CliCommandTestInitializedIntegrationBase {
     }
 
     @Test
-    @DisplayName("Should update config with hocon format when valid cluster-url is given")
+    @DisplayName("Should update config with hocon format when valid cluster-endpoint-url is given")
     void addConfigKeyValue() {
         // When update default data storage to rocksdb
-        execute("cluster", "config", "update", "--cluster-url", NODE_URL, "{table: {defaultDataStorage: rocksdb}}");
+        execute("cluster", "config", "update", "--cluster-endpoint-url", NODE_URL, "{table: {defaultDataStorage: rocksdb}}");
 
         // Then
         assertAll(
@@ -57,7 +57,7 @@ class ItConfigCommandTest extends CliCommandTestInitializedIntegrationBase {
         );
 
         // When read the updated cluster configuration
-        execute("cluster", "config", "show", "--cluster-url", NODE_URL);
+        execute("cluster", "config", "show", "--cluster-endpoint-url", NODE_URL);
 
         // Then
         assertAll(
@@ -68,10 +68,10 @@ class ItConfigCommandTest extends CliCommandTestInitializedIntegrationBase {
     }
 
     @Test
-    @DisplayName("Should update config with key-value format when valid cluster-url is given")
+    @DisplayName("Should update config with key-value format when valid cluster-endpoint-url is given")
     void updateConfigWithSpecifiedPath() {
         // When update default data storage to rocksdb
-        execute("cluster", "config", "update", "--cluster-url", NODE_URL, "table.defaultDataStorage=rocksdb");
+        execute("cluster", "config", "update", "--cluster-endpoint-url", NODE_URL, "table.defaultDataStorage=rocksdb");
 
         // Then
         assertAll(
@@ -81,7 +81,7 @@ class ItConfigCommandTest extends CliCommandTestInitializedIntegrationBase {
         );
 
         // When read the updated cluster configuration
-        execute("cluster", "config", "show", "--cluster-url", NODE_URL);
+        execute("cluster", "config", "show", "--cluster-endpoint-url", NODE_URL);
 
         // Then
         assertAll(
diff --git a/modules/cli/src/integrationTest/java/org/apache/ignite/cli/deprecated/ItClusterCommandTest.java b/modules/cli/src/integrationTest/java/org/apache/ignite/cli/deprecated/ItClusterCommandTest.java
index e83df0845..9aea8e4d8 100644
--- a/modules/cli/src/integrationTest/java/org/apache/ignite/cli/deprecated/ItClusterCommandTest.java
+++ b/modules/cli/src/integrationTest/java/org/apache/ignite/cli/deprecated/ItClusterCommandTest.java
@@ -170,7 +170,7 @@ class ItClusterCommandTest extends AbstractCliIntegrationTest {
     void initClusterWithNodesOfDifferentRoles(TestInfo testInfo) {
         int exitCode = cmd(ctx).execute(
                 "cluster", "init",
-                "--cluster-url", FIRST_NODE.restHostPort(),
+                "--cluster-endpoint-url", FIRST_NODE.restHostPort(),
                 "--meta-storage-node", SECOND_NODE.nodeName(testInfo),
                 "--cmg-node", THIRD_NODE.nodeName(testInfo),
                 "--cluster-name", "ignite-cluster"
diff --git a/modules/cli/src/main/java/org/apache/ignite/cli/commands/OptionsConstants.java b/modules/cli/src/main/java/org/apache/ignite/cli/commands/OptionsConstants.java
new file mode 100644
index 000000000..934e72d2a
--- /dev/null
+++ b/modules/cli/src/main/java/org/apache/ignite/cli/commands/OptionsConstants.java
@@ -0,0 +1,50 @@
+/*
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
+ *
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+
+package org.apache.ignite.cli.commands;
+
+import org.apache.ignite.cli.config.ConfigConstants;
+
+/**
+ * Constants to use in {@code Option} annotations for commands.
+ */
+public class OptionsConstants {
+    /**
+     * Cluster endpoint URL option name.
+     */
+    public static final String CLUSTER_URL_OPTION = "--cluster-endpoint-url";
+
+    /**
+     * Cluster endpoint URL option description.
+     */
+    public static final String CLUSTER_URL_DESC = "URL of cluster endpoint.";
+
+    /**
+     * Cluster endpoint URL option description key.
+     */
+    public static final String CLUSTER_URL_KEY = ConfigConstants.CLUSTER_URL;
+
+    /**
+     * Node URL option name.
+     */
+    public static final String NODE_URL_OPTION = "--node-url";
+
+    /**
+     * Node URL option description.
+     */
+    public static final String NODE_URL_DESC = "URL of ignite node.";
+}
diff --git a/modules/cli/src/main/java/org/apache/ignite/cli/commands/cluster/config/ClusterConfigShowReplSubCommand.java b/modules/cli/src/main/java/org/apache/ignite/cli/commands/cluster/config/ClusterConfigShowReplSubCommand.java
index 0dd77f40d..8675aa0e8 100644
--- a/modules/cli/src/main/java/org/apache/ignite/cli/commands/cluster/config/ClusterConfigShowReplSubCommand.java
+++ b/modules/cli/src/main/java/org/apache/ignite/cli/commands/cluster/config/ClusterConfigShowReplSubCommand.java
@@ -17,6 +17,10 @@
 
 package org.apache.ignite.cli.commands.cluster.config;
 
+import static org.apache.ignite.cli.commands.OptionsConstants.CLUSTER_URL_DESC;
+import static org.apache.ignite.cli.commands.OptionsConstants.CLUSTER_URL_KEY;
+import static org.apache.ignite.cli.commands.OptionsConstants.CLUSTER_URL_OPTION;
+
 import jakarta.inject.Inject;
 import org.apache.ignite.cli.call.configuration.ClusterConfigShowCall;
 import org.apache.ignite.cli.call.configuration.ClusterConfigShowCallInput;
@@ -45,9 +49,9 @@ public class ClusterConfigShowReplSubCommand extends BaseCommand implements Runn
     private String selector;
 
     /**
-     * Node url option.
+     * Cluster endpoint URL option.
      */
-    @Option(names = {"--cluster-url"}, description = "Url to Ignite node.")
+    @Option(names = {CLUSTER_URL_OPTION}, description = CLUSTER_URL_DESC, descriptionKey = CLUSTER_URL_KEY)
     private String clusterUrl;
 
     @Inject
diff --git a/modules/cli/src/main/java/org/apache/ignite/cli/commands/cluster/config/ClusterConfigShowSubCommand.java b/modules/cli/src/main/java/org/apache/ignite/cli/commands/cluster/config/ClusterConfigShowSubCommand.java
index 54f69fe79..259c93293 100644
--- a/modules/cli/src/main/java/org/apache/ignite/cli/commands/cluster/config/ClusterConfigShowSubCommand.java
+++ b/modules/cli/src/main/java/org/apache/ignite/cli/commands/cluster/config/ClusterConfigShowSubCommand.java
@@ -17,6 +17,10 @@
 
 package org.apache.ignite.cli.commands.cluster.config;
 
+import static org.apache.ignite.cli.commands.OptionsConstants.CLUSTER_URL_DESC;
+import static org.apache.ignite.cli.commands.OptionsConstants.CLUSTER_URL_KEY;
+import static org.apache.ignite.cli.commands.OptionsConstants.CLUSTER_URL_OPTION;
+
 import jakarta.inject.Inject;
 import java.util.concurrent.Callable;
 import org.apache.ignite.cli.call.configuration.ClusterConfigShowCall;
@@ -41,9 +45,9 @@ public class ClusterConfigShowSubCommand extends BaseCommand implements Callable
     private String selector;
 
     /**
-     * Node url option.
+     * Cluster endpoint URL option.
      */
-    @Option(names = {"--cluster-url"}, description = "Url to ignite node.", descriptionKey = "ignite.cluster-url")
+    @Option(names = {CLUSTER_URL_OPTION}, description = CLUSTER_URL_DESC, descriptionKey = CLUSTER_URL_KEY)
     private String clusterUrl;
 
     @Inject
diff --git a/modules/cli/src/main/java/org/apache/ignite/cli/commands/cluster/config/ClusterConfigUpdateReplSubCommand.java b/modules/cli/src/main/java/org/apache/ignite/cli/commands/cluster/config/ClusterConfigUpdateReplSubCommand.java
index b8863f712..5e8c75920 100644
--- a/modules/cli/src/main/java/org/apache/ignite/cli/commands/cluster/config/ClusterConfigUpdateReplSubCommand.java
+++ b/modules/cli/src/main/java/org/apache/ignite/cli/commands/cluster/config/ClusterConfigUpdateReplSubCommand.java
@@ -17,6 +17,10 @@
 
 package org.apache.ignite.cli.commands.cluster.config;
 
+import static org.apache.ignite.cli.commands.OptionsConstants.CLUSTER_URL_DESC;
+import static org.apache.ignite.cli.commands.OptionsConstants.CLUSTER_URL_KEY;
+import static org.apache.ignite.cli.commands.OptionsConstants.CLUSTER_URL_OPTION;
+
 import jakarta.inject.Inject;
 import jakarta.inject.Singleton;
 import org.apache.ignite.cli.call.configuration.ClusterConfigUpdateCall;
@@ -37,9 +41,9 @@ import picocli.CommandLine.Parameters;
 @Singleton
 public class ClusterConfigUpdateReplSubCommand extends BaseCommand implements Runnable {
     /**
-     * Cluster url option.
+     * Cluster endpoint URL option.
      */
-    @Option(names = {"--cluster-url"}, description = "Url to Ignite node.", descriptionKey = "ignite.cluster-url")
+    @Option(names = {CLUSTER_URL_OPTION}, description = CLUSTER_URL_DESC, descriptionKey = CLUSTER_URL_KEY)
     private String clusterUrl;
 
     /**
diff --git a/modules/cli/src/main/java/org/apache/ignite/cli/commands/cluster/config/ClusterConfigUpdateSubCommand.java b/modules/cli/src/main/java/org/apache/ignite/cli/commands/cluster/config/ClusterConfigUpdateSubCommand.java
index 1e7932243..b5d337b3a 100644
--- a/modules/cli/src/main/java/org/apache/ignite/cli/commands/cluster/config/ClusterConfigUpdateSubCommand.java
+++ b/modules/cli/src/main/java/org/apache/ignite/cli/commands/cluster/config/ClusterConfigUpdateSubCommand.java
@@ -17,6 +17,10 @@
 
 package org.apache.ignite.cli.commands.cluster.config;
 
+import static org.apache.ignite.cli.commands.OptionsConstants.CLUSTER_URL_DESC;
+import static org.apache.ignite.cli.commands.OptionsConstants.CLUSTER_URL_KEY;
+import static org.apache.ignite.cli.commands.OptionsConstants.CLUSTER_URL_OPTION;
+
 import jakarta.inject.Inject;
 import jakarta.inject.Singleton;
 import java.util.concurrent.Callable;
@@ -39,9 +43,9 @@ public class ClusterConfigUpdateSubCommand extends BaseCommand implements Callab
     ClusterConfigUpdateCall call;
 
     /**
-     * Cluster url option.
+     * Cluster endpoint URL option.
      */
-    @Option(names = {"--cluster-url"}, description = "Url to Ignite node.", descriptionKey = "ignite.cluster-url")
+    @Option(names = {CLUSTER_URL_OPTION}, description = CLUSTER_URL_DESC, descriptionKey = CLUSTER_URL_KEY)
     private String clusterUrl;
 
     /**
diff --git a/modules/cli/src/main/java/org/apache/ignite/cli/commands/cluster/init/ClusterInitReplSubCommand.java b/modules/cli/src/main/java/org/apache/ignite/cli/commands/cluster/init/ClusterInitReplSubCommand.java
index 09f14ae3f..61f8ea774 100644
--- a/modules/cli/src/main/java/org/apache/ignite/cli/commands/cluster/init/ClusterInitReplSubCommand.java
+++ b/modules/cli/src/main/java/org/apache/ignite/cli/commands/cluster/init/ClusterInitReplSubCommand.java
@@ -17,6 +17,9 @@
 
 package org.apache.ignite.cli.commands.cluster.init;
 
+import static org.apache.ignite.cli.commands.OptionsConstants.CLUSTER_URL_DESC;
+import static org.apache.ignite.cli.commands.OptionsConstants.CLUSTER_URL_KEY;
+import static org.apache.ignite.cli.commands.OptionsConstants.CLUSTER_URL_OPTION;
 import static picocli.CommandLine.Command;
 
 import jakarta.inject.Inject;
@@ -37,11 +40,11 @@ import picocli.CommandLine.Option;
 public class ClusterInitReplSubCommand extends BaseCommand implements Runnable {
 
     /**
-     * Node url option.
+     * Cluster endpoint URL option.
      */
     @Option(
-            names = {"--cluster-url"}, description = "Url to ignite node.",
-            descriptionKey = "ignite.cluster-url", defaultValue = "http://localhost:10300"
+            names = {CLUSTER_URL_OPTION}, description = CLUSTER_URL_DESC, descriptionKey = CLUSTER_URL_KEY,
+            defaultValue = "http://localhost:10300"
     )
     private String clusterUrl;
 
@@ -86,7 +89,8 @@ public class ClusterInitReplSubCommand extends BaseCommand implements Runnable {
         } else if (clusterUrl != null) {
             input.clusterUrl(clusterUrl);
         } else {
-            spec.commandLine().getErr().println("You are not connected to node. Run 'connect' command or use '--node-endpoint' option.");
+            spec.commandLine().getErr().println("You are not connected to node. Run 'connect' command or use '"
+                    + CLUSTER_URL_OPTION + "' option.");
             return;
         }
 
diff --git a/modules/cli/src/main/java/org/apache/ignite/cli/commands/cluster/init/ClusterInitSubCommand.java b/modules/cli/src/main/java/org/apache/ignite/cli/commands/cluster/init/ClusterInitSubCommand.java
index bac8a7072..dbe2d6630 100644
--- a/modules/cli/src/main/java/org/apache/ignite/cli/commands/cluster/init/ClusterInitSubCommand.java
+++ b/modules/cli/src/main/java/org/apache/ignite/cli/commands/cluster/init/ClusterInitSubCommand.java
@@ -17,6 +17,10 @@
 
 package org.apache.ignite.cli.commands.cluster.init;
 
+import static org.apache.ignite.cli.commands.OptionsConstants.CLUSTER_URL_DESC;
+import static org.apache.ignite.cli.commands.OptionsConstants.CLUSTER_URL_KEY;
+import static org.apache.ignite.cli.commands.OptionsConstants.CLUSTER_URL_OPTION;
+
 import jakarta.inject.Inject;
 import java.util.ArrayList;
 import java.util.List;
@@ -35,11 +39,11 @@ import picocli.CommandLine.Option;
 public class ClusterInitSubCommand extends BaseCommand implements Callable<Integer> {
 
     /**
-     * Node url option.
+     * Cluster endpoint URL option.
      */
     @Option(
-            names = {"--cluster-url"}, description = "Url to ignite node.",
-            descriptionKey = "ignite.cluster-url", defaultValue = "http://localhost:10300"
+            names = {CLUSTER_URL_OPTION}, description = CLUSTER_URL_DESC, descriptionKey = CLUSTER_URL_KEY,
+            defaultValue = "http://localhost:10300"
     )
     private String clusterUrl;
 
diff --git a/modules/cli/src/main/java/org/apache/ignite/cli/commands/cluster/status/ClusterStatusReplSubCommand.java b/modules/cli/src/main/java/org/apache/ignite/cli/commands/cluster/status/ClusterStatusReplSubCommand.java
index 6900cfeee..9f0166cc3 100644
--- a/modules/cli/src/main/java/org/apache/ignite/cli/commands/cluster/status/ClusterStatusReplSubCommand.java
+++ b/modules/cli/src/main/java/org/apache/ignite/cli/commands/cluster/status/ClusterStatusReplSubCommand.java
@@ -17,6 +17,10 @@
 
 package org.apache.ignite.cli.commands.cluster.status;
 
+import static org.apache.ignite.cli.commands.OptionsConstants.CLUSTER_URL_DESC;
+import static org.apache.ignite.cli.commands.OptionsConstants.CLUSTER_URL_KEY;
+import static org.apache.ignite.cli.commands.OptionsConstants.CLUSTER_URL_OPTION;
+
 import jakarta.inject.Inject;
 import jakarta.inject.Singleton;
 import org.apache.ignite.cli.call.cluster.status.ClusterStatusCall;
@@ -36,10 +40,10 @@ import picocli.CommandLine.Option;
 public class ClusterStatusReplSubCommand extends BaseCommand implements Runnable {
 
     /**
-     * Cluster url option.
+     * Cluster endpoint URL option.
      */
     @SuppressWarnings("PMD.UnusedPrivateField")
-    @Option(names = {"--cluster-url"}, description = "Url to cluster node.", descriptionKey = "ignite.cluster-url")
+    @Option(names = {CLUSTER_URL_OPTION}, description = CLUSTER_URL_DESC, descriptionKey = CLUSTER_URL_KEY)
     private String clusterUrl;
 
     @Inject
@@ -58,7 +62,8 @@ public class ClusterStatusReplSubCommand extends BaseCommand implements Runnable
         } else if (session.isConnectedToNode()) {
             inputUrl = session.nodeUrl();
         } else {
-            spec.commandLine().getErr().println("You are not connected to node. Run 'connect' command or use '--cluster-url' option.");
+            spec.commandLine().getErr().println("You are not connected to node. Run 'connect' command or use '"
+                    + CLUSTER_URL_OPTION + "' option.");
             return;
         }
 
diff --git a/modules/cli/src/main/java/org/apache/ignite/cli/commands/cluster/status/ClusterStatusSubCommand.java b/modules/cli/src/main/java/org/apache/ignite/cli/commands/cluster/status/ClusterStatusSubCommand.java
index c386dd03b..7b5a7ac9e 100644
--- a/modules/cli/src/main/java/org/apache/ignite/cli/commands/cluster/status/ClusterStatusSubCommand.java
+++ b/modules/cli/src/main/java/org/apache/ignite/cli/commands/cluster/status/ClusterStatusSubCommand.java
@@ -17,6 +17,10 @@
 
 package org.apache.ignite.cli.commands.cluster.status;
 
+import static org.apache.ignite.cli.commands.OptionsConstants.CLUSTER_URL_DESC;
+import static org.apache.ignite.cli.commands.OptionsConstants.CLUSTER_URL_KEY;
+import static org.apache.ignite.cli.commands.OptionsConstants.CLUSTER_URL_OPTION;
+
 import jakarta.inject.Inject;
 import jakarta.inject.Singleton;
 import java.util.concurrent.Callable;
@@ -38,10 +42,10 @@ import picocli.CommandLine.Option;
 public class ClusterStatusSubCommand extends BaseCommand implements Callable<Integer> {
 
     /**
-     * Cluster url option.
+     * Cluster endpoint URL option.
      */
     @SuppressWarnings("PMD.UnusedPrivateField")
-    @Option(names = {"--cluster-url"}, description = "Url to cluster node.", descriptionKey = "ignite.cluster-url")
+    @Option(names = {CLUSTER_URL_OPTION}, description = CLUSTER_URL_DESC, descriptionKey = CLUSTER_URL_KEY)
     private String clusterUrl;
 
     @Inject
diff --git a/modules/cli/src/main/java/org/apache/ignite/cli/commands/node/config/NodeConfigShowReplSubCommand.java b/modules/cli/src/main/java/org/apache/ignite/cli/commands/node/config/NodeConfigShowReplSubCommand.java
index c5bb5bcd4..07db72b2b 100644
--- a/modules/cli/src/main/java/org/apache/ignite/cli/commands/node/config/NodeConfigShowReplSubCommand.java
+++ b/modules/cli/src/main/java/org/apache/ignite/cli/commands/node/config/NodeConfigShowReplSubCommand.java
@@ -17,6 +17,10 @@
 
 package org.apache.ignite.cli.commands.node.config;
 
+import static org.apache.ignite.cli.commands.OptionsConstants.CLUSTER_URL_KEY;
+import static org.apache.ignite.cli.commands.OptionsConstants.NODE_URL_DESC;
+import static org.apache.ignite.cli.commands.OptionsConstants.NODE_URL_OPTION;
+
 import jakarta.inject.Inject;
 import org.apache.ignite.cli.call.configuration.NodeConfigShowCall;
 import org.apache.ignite.cli.call.configuration.NodeConfigShowCallInput;
@@ -41,11 +45,9 @@ public class NodeConfigShowReplSubCommand extends BaseCommand implements Runnabl
     private String selector;
 
     /**
-     * Node url option.
+     * Node URL option.
      */
-    @Option(
-            names = {"--node-url"}, description = "Url to Ignite node."
-    )
+    @Option(names = {NODE_URL_OPTION}, description = NODE_URL_DESC, descriptionKey = CLUSTER_URL_KEY)
     private String nodeUrl;
 
     @Inject
diff --git a/modules/cli/src/main/java/org/apache/ignite/cli/commands/node/config/NodeConfigShowSubCommand.java b/modules/cli/src/main/java/org/apache/ignite/cli/commands/node/config/NodeConfigShowSubCommand.java
index e23c418b8..ac2a3d92c 100644
--- a/modules/cli/src/main/java/org/apache/ignite/cli/commands/node/config/NodeConfigShowSubCommand.java
+++ b/modules/cli/src/main/java/org/apache/ignite/cli/commands/node/config/NodeConfigShowSubCommand.java
@@ -17,6 +17,10 @@
 
 package org.apache.ignite.cli.commands.node.config;
 
+import static org.apache.ignite.cli.commands.OptionsConstants.CLUSTER_URL_KEY;
+import static org.apache.ignite.cli.commands.OptionsConstants.NODE_URL_DESC;
+import static org.apache.ignite.cli.commands.OptionsConstants.NODE_URL_OPTION;
+
 import jakarta.inject.Inject;
 import java.util.concurrent.Callable;
 import org.apache.ignite.cli.call.configuration.NodeConfigShowCall;
@@ -41,9 +45,9 @@ public class NodeConfigShowSubCommand extends BaseCommand implements Callable<In
     private String selector;
 
     /**
-     * Node url option.
+     * Node URL option.
      */
-    @Option(names = {"--node-url"}, description = "Url to ignite node.", descriptionKey = "ignite.cluster-url")
+    @Option(names = {NODE_URL_OPTION}, description = NODE_URL_DESC, descriptionKey = CLUSTER_URL_KEY)
     private String nodeUrl;
 
     @Inject
diff --git a/modules/cli/src/main/java/org/apache/ignite/cli/commands/node/config/NodeConfigUpdateReplSubCommand.java b/modules/cli/src/main/java/org/apache/ignite/cli/commands/node/config/NodeConfigUpdateReplSubCommand.java
index c7918ccd8..918b7ef1b 100644
--- a/modules/cli/src/main/java/org/apache/ignite/cli/commands/node/config/NodeConfigUpdateReplSubCommand.java
+++ b/modules/cli/src/main/java/org/apache/ignite/cli/commands/node/config/NodeConfigUpdateReplSubCommand.java
@@ -17,6 +17,10 @@
 
 package org.apache.ignite.cli.commands.node.config;
 
+import static org.apache.ignite.cli.commands.OptionsConstants.CLUSTER_URL_KEY;
+import static org.apache.ignite.cli.commands.OptionsConstants.NODE_URL_DESC;
+import static org.apache.ignite.cli.commands.OptionsConstants.NODE_URL_OPTION;
+
 import jakarta.inject.Inject;
 import jakarta.inject.Singleton;
 import org.apache.ignite.cli.call.configuration.NodeConfigUpdateCall;
@@ -37,9 +41,9 @@ import picocli.CommandLine.Parameters;
 @Singleton
 public class NodeConfigUpdateReplSubCommand extends BaseCommand implements Runnable {
     /**
-     * Node url option.
+     * Node URL option.
      */
-    @Option(names = {"--node-url"}, description = "Url to Ignite node.", descriptionKey = "ignite.cluster-url")
+    @Option(names = {NODE_URL_OPTION}, description = NODE_URL_DESC, descriptionKey = CLUSTER_URL_KEY)
     private String nodeUrl;
 
     /**
diff --git a/modules/cli/src/main/java/org/apache/ignite/cli/commands/node/config/NodeConfigUpdateSubCommand.java b/modules/cli/src/main/java/org/apache/ignite/cli/commands/node/config/NodeConfigUpdateSubCommand.java
index b5b24eb67..f2f8006b0 100644
--- a/modules/cli/src/main/java/org/apache/ignite/cli/commands/node/config/NodeConfigUpdateSubCommand.java
+++ b/modules/cli/src/main/java/org/apache/ignite/cli/commands/node/config/NodeConfigUpdateSubCommand.java
@@ -17,6 +17,10 @@
 
 package org.apache.ignite.cli.commands.node.config;
 
+import static org.apache.ignite.cli.commands.OptionsConstants.CLUSTER_URL_KEY;
+import static org.apache.ignite.cli.commands.OptionsConstants.NODE_URL_DESC;
+import static org.apache.ignite.cli.commands.OptionsConstants.NODE_URL_OPTION;
+
 import jakarta.inject.Inject;
 import jakarta.inject.Singleton;
 import java.util.concurrent.Callable;
@@ -36,9 +40,9 @@ import picocli.CommandLine.Parameters;
 @Singleton
 public class NodeConfigUpdateSubCommand extends BaseCommand implements Callable<Integer> {
     /**
-     * Node url option.
+     * Node URL option.
      */
-    @Option(names = {"--node-url"}, description = "Url to Ignite node.", descriptionKey = "ignite.cluster-url")
+    @Option(names = {NODE_URL_OPTION}, description = NODE_URL_DESC, descriptionKey = CLUSTER_URL_KEY)
     private String nodeUrl;
 
     /**
diff --git a/modules/cli/src/main/java/org/apache/ignite/cli/commands/node/status/NodeStatusReplSubCommand.java b/modules/cli/src/main/java/org/apache/ignite/cli/commands/node/status/NodeStatusReplSubCommand.java
index ec526518e..43672b05f 100644
--- a/modules/cli/src/main/java/org/apache/ignite/cli/commands/node/status/NodeStatusReplSubCommand.java
+++ b/modules/cli/src/main/java/org/apache/ignite/cli/commands/node/status/NodeStatusReplSubCommand.java
@@ -17,6 +17,10 @@
 
 package org.apache.ignite.cli.commands.node.status;
 
+import static org.apache.ignite.cli.commands.OptionsConstants.CLUSTER_URL_KEY;
+import static org.apache.ignite.cli.commands.OptionsConstants.NODE_URL_DESC;
+import static org.apache.ignite.cli.commands.OptionsConstants.NODE_URL_OPTION;
+
 import jakarta.inject.Inject;
 import jakarta.inject.Singleton;
 import java.util.concurrent.Callable;
@@ -38,12 +42,10 @@ import picocli.CommandLine.Option;
 public class NodeStatusReplSubCommand extends BaseCommand implements Callable<Integer> {
 
     /**
-     * Node url option.
+     * Node URL option.
      */
     @SuppressWarnings("PMD.UnusedPrivateField")
-    @Option(
-            names = {"--node-url"}, description = "Url to node.", descriptionKey = "ignite.cluster-url"
-    )
+    @Option(names = {NODE_URL_OPTION}, description = NODE_URL_DESC, descriptionKey = CLUSTER_URL_KEY)
     private String nodeUrl;
 
     @Inject
@@ -62,7 +64,8 @@ public class NodeStatusReplSubCommand extends BaseCommand implements Callable<In
         } else if (session.isConnectedToNode()) {
             inputUrl = session.nodeUrl();
         } else {
-            spec.commandLine().getErr().println("You are not connected to node. Run 'connect' command or use '--node-url' option.");
+            spec.commandLine().getErr().println("You are not connected to node. Run 'connect' command or use '"
+                    + NODE_URL_OPTION + "' option.");
             return 2;
         }
 
diff --git a/modules/cli/src/main/java/org/apache/ignite/cli/commands/node/status/NodeStatusSubCommand.java b/modules/cli/src/main/java/org/apache/ignite/cli/commands/node/status/NodeStatusSubCommand.java
index 78abc3620..6a4240279 100644
--- a/modules/cli/src/main/java/org/apache/ignite/cli/commands/node/status/NodeStatusSubCommand.java
+++ b/modules/cli/src/main/java/org/apache/ignite/cli/commands/node/status/NodeStatusSubCommand.java
@@ -17,6 +17,10 @@
 
 package org.apache.ignite.cli.commands.node.status;
 
+import static org.apache.ignite.cli.commands.OptionsConstants.CLUSTER_URL_KEY;
+import static org.apache.ignite.cli.commands.OptionsConstants.NODE_URL_DESC;
+import static org.apache.ignite.cli.commands.OptionsConstants.NODE_URL_OPTION;
+
 import jakarta.inject.Inject;
 import jakarta.inject.Singleton;
 import java.util.concurrent.Callable;
@@ -37,10 +41,10 @@ import picocli.CommandLine.Option;
 public class NodeStatusSubCommand extends BaseCommand implements Callable<Integer> {
 
     /**
-     * Node url option.
+     * Node URL option.
      */
     @SuppressWarnings("PMD.UnusedPrivateField")
-    @Option(names = {"--node-url"}, description = "Url to node.", descriptionKey = "ignite.cluster-url")
+    @Option(names = {NODE_URL_OPTION}, description = NODE_URL_DESC, descriptionKey = CLUSTER_URL_KEY)
     private String nodeUrl;
 
     @Inject
diff --git a/modules/cli/src/main/java/org/apache/ignite/cli/commands/questions/ConnectToClusterQuestion.java b/modules/cli/src/main/java/org/apache/ignite/cli/commands/questions/ConnectToClusterQuestion.java
index 061f17783..81dc6ac54 100644
--- a/modules/cli/src/main/java/org/apache/ignite/cli/commands/questions/ConnectToClusterQuestion.java
+++ b/modules/cli/src/main/java/org/apache/ignite/cli/commands/questions/ConnectToClusterQuestion.java
@@ -22,6 +22,7 @@ import jakarta.inject.Singleton;
 import java.util.Objects;
 import org.apache.ignite.cli.call.connect.ConnectCall;
 import org.apache.ignite.cli.call.connect.ConnectCallInput;
+import org.apache.ignite.cli.config.ConfigConstants;
 import org.apache.ignite.cli.config.ConfigManagerProvider;
 import org.apache.ignite.cli.core.flow.Flowable;
 import org.apache.ignite.cli.core.flow.builder.FlowBuilder;
@@ -53,7 +54,7 @@ public class ConnectToClusterQuestion {
      * @return {@link FlowBuilder} instance with question in case when cluster url.
      */
     public FlowBuilder<Void, String> askQuestionIfNotConnected(String clusterUrl) {
-        String clusterProperty = provider.get().getCurrentProperty("ignite.cluster-url");
+        String clusterProperty = provider.get().getCurrentProperty(ConfigConstants.CLUSTER_URL);
         String question = "You are not connected to node. Do you want to connect to the default node "
                 + clusterProperty + " ? [Y/n] ";
 
diff --git a/modules/cli/src/main/java/org/apache/ignite/cli/commands/topology/LogicalTopologyReplSubCommand.java b/modules/cli/src/main/java/org/apache/ignite/cli/commands/topology/LogicalTopologyReplSubCommand.java
index 2cf9ccec6..e1902c637 100644
--- a/modules/cli/src/main/java/org/apache/ignite/cli/commands/topology/LogicalTopologyReplSubCommand.java
+++ b/modules/cli/src/main/java/org/apache/ignite/cli/commands/topology/LogicalTopologyReplSubCommand.java
@@ -17,6 +17,10 @@
 
 package org.apache.ignite.cli.commands.topology;
 
+import static org.apache.ignite.cli.commands.OptionsConstants.CLUSTER_URL_DESC;
+import static org.apache.ignite.cli.commands.OptionsConstants.CLUSTER_URL_KEY;
+import static org.apache.ignite.cli.commands.OptionsConstants.CLUSTER_URL_OPTION;
+
 import jakarta.inject.Inject;
 import java.util.concurrent.Callable;
 import org.apache.ignite.cli.call.cluster.topology.LogicalTopologyCall;
@@ -35,9 +39,9 @@ import picocli.CommandLine.Option;
 @Command(name = "logical")
 public class LogicalTopologyReplSubCommand extends BaseCommand implements Callable<Integer> {
     /**
-     * Node url option.
+     * Cluster endpoint URL option.
      */
-    @Option(names = {"--cluster-url"}, description = "Url to ignite node.", descriptionKey = "ignite.cluster-url")
+    @Option(names = {CLUSTER_URL_OPTION}, description = CLUSTER_URL_DESC, descriptionKey = CLUSTER_URL_KEY)
     private String clusterUrl;
 
     @Inject
@@ -56,7 +60,8 @@ public class LogicalTopologyReplSubCommand extends BaseCommand implements Callab
         } else if (session.isConnectedToNode())  {
             inputBuilder.clusterUrl(session.nodeUrl());
         } else {
-            spec.commandLine().getErr().println("You are not connected to node. Run 'connect' command or use '--cluster-url' option.");
+            spec.commandLine().getErr().println("You are not connected to node. Run 'connect' command or use '"
+                    + CLUSTER_URL_OPTION + "' option.");
             return 2;
         }
 
diff --git a/modules/cli/src/main/java/org/apache/ignite/cli/commands/topology/LogicalTopologySubCommand.java b/modules/cli/src/main/java/org/apache/ignite/cli/commands/topology/LogicalTopologySubCommand.java
index 08de59243..27bca3d24 100644
--- a/modules/cli/src/main/java/org/apache/ignite/cli/commands/topology/LogicalTopologySubCommand.java
+++ b/modules/cli/src/main/java/org/apache/ignite/cli/commands/topology/LogicalTopologySubCommand.java
@@ -17,6 +17,10 @@
 
 package org.apache.ignite.cli.commands.topology;
 
+import static org.apache.ignite.cli.commands.OptionsConstants.CLUSTER_URL_DESC;
+import static org.apache.ignite.cli.commands.OptionsConstants.CLUSTER_URL_KEY;
+import static org.apache.ignite.cli.commands.OptionsConstants.CLUSTER_URL_OPTION;
+
 import jakarta.inject.Inject;
 import java.util.concurrent.Callable;
 import org.apache.ignite.cli.call.cluster.topology.LogicalTopologyCall;
@@ -33,9 +37,9 @@ import picocli.CommandLine.Option;
 @Command(name = "logical")
 public class LogicalTopologySubCommand extends BaseCommand implements Callable<Integer> {
     /**
-     * Node url option.
+     * Cluster endpoint URL option.
      */
-    @Option(names = {"--cluster-url"}, description = "Url to ignite node.", descriptionKey = "ignite.cluster-url")
+    @Option(names = {CLUSTER_URL_OPTION}, description = CLUSTER_URL_DESC, descriptionKey = CLUSTER_URL_KEY)
     private String clusterUrl;
 
     @Inject
diff --git a/modules/cli/src/main/java/org/apache/ignite/cli/commands/topology/PhysicalTopologyReplSubCommand.java b/modules/cli/src/main/java/org/apache/ignite/cli/commands/topology/PhysicalTopologyReplSubCommand.java
index 988433c6b..50a9517ee 100644
--- a/modules/cli/src/main/java/org/apache/ignite/cli/commands/topology/PhysicalTopologyReplSubCommand.java
+++ b/modules/cli/src/main/java/org/apache/ignite/cli/commands/topology/PhysicalTopologyReplSubCommand.java
@@ -17,6 +17,10 @@
 
 package org.apache.ignite.cli.commands.topology;
 
+import static org.apache.ignite.cli.commands.OptionsConstants.CLUSTER_URL_DESC;
+import static org.apache.ignite.cli.commands.OptionsConstants.CLUSTER_URL_KEY;
+import static org.apache.ignite.cli.commands.OptionsConstants.CLUSTER_URL_OPTION;
+
 import jakarta.inject.Inject;
 import java.util.concurrent.Callable;
 import org.apache.ignite.cli.call.cluster.topology.PhysicalTopologyCall;
@@ -35,9 +39,9 @@ import picocli.CommandLine.Option;
 @Command(name = "physical")
 public class PhysicalTopologyReplSubCommand extends BaseCommand implements Callable<Integer> {
     /**
-     * Node url option.
+     * Cluster endpoint URL option.
      */
-    @Option(names = {"--cluster-url"}, description = "Url to ignite node.", descriptionKey = "ignite.cluster-url")
+    @Option(names = {CLUSTER_URL_OPTION}, description = CLUSTER_URL_DESC, descriptionKey = CLUSTER_URL_KEY)
     private String clusterUrl;
 
     @Inject
@@ -56,7 +60,8 @@ public class PhysicalTopologyReplSubCommand extends BaseCommand implements Calla
         } else if (session.isConnectedToNode())  {
             inputBuilder.clusterUrl(session.nodeUrl());
         } else {
-            spec.commandLine().getErr().println("You are not connected to node. Run 'connect' command or use '--cluster-url' option.");
+            spec.commandLine().getErr().println("You are not connected to node. Run 'connect' command or use '"
+                    + CLUSTER_URL_OPTION + "' option.");
             return 2;
         }
 
diff --git a/modules/cli/src/main/java/org/apache/ignite/cli/commands/topology/PhysicalTopologySubCommand.java b/modules/cli/src/main/java/org/apache/ignite/cli/commands/topology/PhysicalTopologySubCommand.java
index a76be9dc9..59ad74b96 100644
--- a/modules/cli/src/main/java/org/apache/ignite/cli/commands/topology/PhysicalTopologySubCommand.java
+++ b/modules/cli/src/main/java/org/apache/ignite/cli/commands/topology/PhysicalTopologySubCommand.java
@@ -17,6 +17,10 @@
 
 package org.apache.ignite.cli.commands.topology;
 
+import static org.apache.ignite.cli.commands.OptionsConstants.CLUSTER_URL_DESC;
+import static org.apache.ignite.cli.commands.OptionsConstants.CLUSTER_URL_KEY;
+import static org.apache.ignite.cli.commands.OptionsConstants.CLUSTER_URL_OPTION;
+
 import jakarta.inject.Inject;
 import java.util.concurrent.Callable;
 import org.apache.ignite.cli.call.cluster.topology.PhysicalTopologyCall;
@@ -33,9 +37,9 @@ import picocli.CommandLine.Option;
 @Command(name = "physical")
 public class PhysicalTopologySubCommand extends BaseCommand implements Callable<Integer> {
     /**
-     * Node url option.
+     * Cluster endpoint URL option.
      */
-    @Option(names = {"--cluster-url"}, description = "Url to ignite node.", descriptionKey = "ignite.cluster-url")
+    @Option(names = {CLUSTER_URL_OPTION}, description = CLUSTER_URL_DESC, descriptionKey = CLUSTER_URL_KEY)
     private String clusterUrl;
 
     @Inject
diff --git a/modules/cli/src/main/java/org/apache/ignite/cli/config/ConfigConstants.java b/modules/cli/src/main/java/org/apache/ignite/cli/config/ConfigConstants.java
index fcc2f9864..d8ce17083 100644
--- a/modules/cli/src/main/java/org/apache/ignite/cli/config/ConfigConstants.java
+++ b/modules/cli/src/main/java/org/apache/ignite/cli/config/ConfigConstants.java
@@ -29,7 +29,7 @@ public final class ConfigConstants {
     private static final String CONFIG_FILE_NAME = "defaults";
 
     public static final String CURRENT_PROFILE = "current_profile";
-    public static final String CLUSTER_URL = "ignite.cluster-url";
+    public static final String CLUSTER_URL = "ignite.cluster-endpoint-url";
     public static final String JDBC_URL = "ignite.jdbc-url";
 
     private ConfigConstants() {
diff --git a/modules/cli/src/main/java/org/apache/ignite/cli/core/repl/completer/DynamicCompleterFilter.java b/modules/cli/src/main/java/org/apache/ignite/cli/core/repl/completer/DynamicCompleterFilter.java
index c97c607cb..8b4339ffb 100644
--- a/modules/cli/src/main/java/org/apache/ignite/cli/core/repl/completer/DynamicCompleterFilter.java
+++ b/modules/cli/src/main/java/org/apache/ignite/cli/core/repl/completer/DynamicCompleterFilter.java
@@ -17,6 +17,9 @@
 
 package org.apache.ignite.cli.core.repl.completer;
 
+import static org.apache.ignite.cli.commands.OptionsConstants.CLUSTER_URL_OPTION;
+import static org.apache.ignite.cli.commands.OptionsConstants.NODE_URL_OPTION;
+
 import jakarta.inject.Singleton;
 import java.util.Arrays;
 import org.apache.ignite.cli.core.repl.Session;
@@ -59,6 +62,6 @@ public class DynamicCompleterFilter implements CompleterFilter {
             return true;
         }
 
-        return !session.isConnectedToNode() || (!candidate.equals("--cluster-url") && !candidate.equals("--node-url"));
+        return !session.isConnectedToNode() || (!candidate.equals(CLUSTER_URL_OPTION) && !candidate.equals(NODE_URL_OPTION));
     }
 }
diff --git a/modules/cli/src/main/java/org/apache/ignite/cli/core/repl/completer/NodeUrlProvider.java b/modules/cli/src/main/java/org/apache/ignite/cli/core/repl/completer/NodeUrlProvider.java
index 04792fbe6..ef259e5cf 100644
--- a/modules/cli/src/main/java/org/apache/ignite/cli/core/repl/completer/NodeUrlProvider.java
+++ b/modules/cli/src/main/java/org/apache/ignite/cli/core/repl/completer/NodeUrlProvider.java
@@ -18,6 +18,7 @@
 package org.apache.ignite.cli.core.repl.completer;
 
 import jakarta.inject.Singleton;
+import org.apache.ignite.cli.commands.OptionsConstants;
 import org.apache.ignite.cli.config.ConfigConstants;
 import org.apache.ignite.cli.config.ConfigManagerProvider;
 import org.apache.ignite.cli.core.repl.Session;
@@ -53,8 +54,9 @@ public class NodeUrlProvider {
 
     private String findClusterUrlIn(String[] words) {
         for (String word : words) {
-            if (word.startsWith("--cluster-url=")) {
-                return word.substring("--cluster-url=".length());
+            String prefix = OptionsConstants.CLUSTER_URL_OPTION + "=";
+            if (word.startsWith(prefix)) {
+                return word.substring(prefix.length());
             }
         }
         return null;
diff --git a/modules/cli/src/test/java/org/apache/ignite/cli/commands/UrlOptionsNegativeTest.java b/modules/cli/src/test/java/org/apache/ignite/cli/commands/UrlOptionsNegativeTest.java
index 13f717d1b..9b164c3ff 100644
--- a/modules/cli/src/test/java/org/apache/ignite/cli/commands/UrlOptionsNegativeTest.java
+++ b/modules/cli/src/test/java/org/apache/ignite/cli/commands/UrlOptionsNegativeTest.java
@@ -91,16 +91,16 @@ public class UrlOptionsNegativeTest {
         return List.of(
                 Arguments.arguments(NodeConfigShowSubCommand.class, "--node-url=", List.of()),
                 Arguments.arguments(NodeConfigUpdateSubCommand.class, "--node-url=", List.of("{key: value}")),
-                Arguments.arguments(ClusterConfigShowSubCommand.class, "--cluster-url=", List.of()),
-                Arguments.arguments(ClusterConfigUpdateSubCommand.class, "--cluster-url=", List.of("{key: value}"))
+                Arguments.arguments(ClusterConfigShowSubCommand.class, "--cluster-endpoint-url=", List.of()),
+                Arguments.arguments(ClusterConfigUpdateSubCommand.class, "--cluster-endpoint-url=", List.of("{key: value}"))
         // TODO https://issues.apache.org/jira/browse/IGNITE-17091
-        //                Arguments.arguments(StatusCommand.class, "--cluster-url=", List.of()),
+        //                Arguments.arguments(StatusCommand.class, "--cluster-endpoint-url=", List.of()),
         // TODO https://issues.apache.org/jira/browse/IGNITE-17102
-        //                Arguments.arguments(ClusterShowCommand.class, "--cluster-url=", List.of()),
+        //                Arguments.arguments(ClusterShowCommand.class, "--cluster-endpoint-url=", List.of()),
         // TODO https://issues.apache.org/jira/browse/IGNITE-17092
-        //                Arguments.arguments(TopologyCommand.class, "--cluster-url", List.of()),
+        //                Arguments.arguments(TopologyCommand.class, "--cluster-endpoint-url", List.of()),
         // TODO https://issues.apache.org/jira/browse/IGNITE-17162
-        //                Arguments.arguments(ClusterCommandSpec.InitClusterCommandSpec.class, "---cluster-url=",
+        //                Arguments.arguments(ClusterCommandSpec.InitClusterCommandSpec.class, "---cluster-endpoint-url=",
         //                        List.of("--cluster-name=cluster", "--meta-storage-node=test"))
         );
     }
@@ -109,17 +109,17 @@ public class UrlOptionsNegativeTest {
         return List.of(
                 Arguments.arguments(NodeConfigShowReplSubCommand.class, "--node-url=", List.of()),
                 Arguments.arguments(NodeConfigUpdateReplSubCommand.class, "--node-url=", List.of("{key: value}")),
-                Arguments.arguments(ClusterConfigShowReplSubCommand.class, "--cluster-url=", List.of()),
-                Arguments.arguments(ClusterConfigUpdateReplSubCommand.class, "--cluster-url=", List.of("{key: value}")),
+                Arguments.arguments(ClusterConfigShowReplSubCommand.class, "--cluster-endpoint-url=", List.of()),
+                Arguments.arguments(ClusterConfigUpdateReplSubCommand.class, "--cluster-endpoint-url=", List.of("{key: value}")),
                 Arguments.arguments(ConnectCommand.class, "", List.of())
         // TODO https://issues.apache.org/jira/browse/IGNITE-17091
-        //                Arguments.arguments(StatusReplCommand.class, "--cluster-url=", List.of()),
+        //                Arguments.arguments(StatusReplCommand.class, "--cluster-endpoint-url=", List.of()),
         // TODO https://issues.apache.org/jira/browse/IGNITE-17102
-        //                Arguments.arguments(ClusterShowReplCommand.class, "--cluster-url=", List.of()),
+        //                Arguments.arguments(ClusterShowReplCommand.class, "--cluster-endpoint-url=", List.of()),
         // TODO https://issues.apache.org/jira/browse/IGNITE-17092
-        //                Arguments.arguments(TopologyReplCommand.class, "--cluster-url", List.of()),
+        //                Arguments.arguments(TopologyReplCommand.class, "--cluster-endpoint-url", List.of()),
         // TODO https://issues.apache.org/jira/browse/IGNITE-17162
-        //                Arguments.arguments(ClusterReplCommandSpec.InitClusterCommandSpec.class, "---cluster-url=",
+        //                Arguments.arguments(ClusterReplCommandSpec.InitClusterCommandSpec.class, "---cluster-endpoint-url=",
         //                        List.of("--cluster-name=cluster", "--meta-storage-node=test"))
         );
     }
diff --git a/modules/cli/src/test/java/org/apache/ignite/cli/commands/cliconfig/CliConfigGetSubCommandTest.java b/modules/cli/src/test/java/org/apache/ignite/cli/commands/cliconfig/CliConfigGetSubCommandTest.java
index cc00e6987..057207eb1 100644
--- a/modules/cli/src/test/java/org/apache/ignite/cli/commands/cliconfig/CliConfigGetSubCommandTest.java
+++ b/modules/cli/src/test/java/org/apache/ignite/cli/commands/cliconfig/CliConfigGetSubCommandTest.java
@@ -83,7 +83,7 @@ class CliConfigGetSubCommandTest extends CliCommandTestBase {
     @DisplayName("Only one key is allowed")
     void multipleKeys() {
         // When executed with multiple keys
-        execute("ignite.cluster-url", "ignite.jdbc-url");
+        execute("ignite.cluster-endpoint-url", "ignite.jdbc-url");
 
         assertAll(
                 () -> assertExitCodeIs(2),
diff --git a/modules/cli/src/test/java/org/apache/ignite/cli/commands/cliconfig/CliConfigSetSubCommandTest.java b/modules/cli/src/test/java/org/apache/ignite/cli/commands/cliconfig/CliConfigSetSubCommandTest.java
index 6981dd110..e568fdf5d 100644
--- a/modules/cli/src/test/java/org/apache/ignite/cli/commands/cliconfig/CliConfigSetSubCommandTest.java
+++ b/modules/cli/src/test/java/org/apache/ignite/cli/commands/cliconfig/CliConfigSetSubCommandTest.java
@@ -61,12 +61,12 @@ class CliConfigSetSubCommandTest extends CliCommandTestBase {
     @DisplayName("Missing value")
     void singleKey() {
         // When executed with key
-        execute("ignite.cluster-url");
+        execute("ignite.cluster-endpoint-url");
 
         assertAll(
                 () -> assertExitCodeIs(2),
                 this::assertOutputIsEmpty,
-                () -> assertErrOutputContains("should be in KEY=VALUE format but was ignite.cluster-url")
+                () -> assertErrOutputContains("should be in KEY=VALUE format but was ignite.cluster-endpoint-url")
         );
     }
 
@@ -88,7 +88,7 @@ class CliConfigSetSubCommandTest extends CliCommandTestBase {
     @DisplayName("Sets multiple values")
     void multipleKeys() {
         // When executed with multiple keys
-        execute("ignite.cluster-url=test", "ignite.jdbc-url=test2");
+        execute("ignite.cluster-endpoint-url=test", "ignite.jdbc-url=test2");
 
         ConfigManager configManager = configManagerProvider.get();
 
@@ -105,7 +105,7 @@ class CliConfigSetSubCommandTest extends CliCommandTestBase {
     @DisplayName("Set with profile")
     public void testWithProfile() {
         // When executed with multiple keys
-        execute("ignite.cluster-url=test ignite.jdbc-url=test2 --profile owner");
+        execute("ignite.cluster-endpoint-url=test ignite.jdbc-url=test2 --profile owner");
 
         ConfigManager configManager = configManagerProvider.get();
 
@@ -121,7 +121,7 @@ class CliConfigSetSubCommandTest extends CliCommandTestBase {
 
     @Test
     public void testWithNotExistedProfile() {
-        execute("ignite.cluster-url=test ignite.jdbc-url=test2 --profile notExist");
+        execute("ignite.cluster-endpoint-url=test ignite.jdbc-url=test2 --profile notExist");
 
         ConfigManager configManager = configManagerProvider.get();
 
diff --git a/modules/cli/src/test/java/org/apache/ignite/cli/commands/cliconfig/ConfigManagerTest.java b/modules/cli/src/test/java/org/apache/ignite/cli/commands/cliconfig/ConfigManagerTest.java
index 2e7058980..10e99524a 100644
--- a/modules/cli/src/test/java/org/apache/ignite/cli/commands/cliconfig/ConfigManagerTest.java
+++ b/modules/cli/src/test/java/org/apache/ignite/cli/commands/cliconfig/ConfigManagerTest.java
@@ -29,10 +29,10 @@ class ConfigManagerTest {
         File tempFile = TestConfigManagerHelper.createSectionWithInternalPart();
         IniConfigManager configManager = new IniConfigManager(tempFile);
 
-        configManager.setProperty("ignite.cluster-url", "test");
+        configManager.setProperty("ignite.cluster-endpoint-url", "test");
 
         IniConfigManager configAfterSave = new IniConfigManager(tempFile);
-        assertThat(configAfterSave.getCurrentProperty("ignite.cluster-url")).isEqualTo("test");
+        assertThat(configAfterSave.getCurrentProperty("ignite.cluster-endpoint-url")).isEqualTo("test");
     }
 
     @Test
diff --git a/modules/cli/src/test/java/org/apache/ignite/cli/deprecated/IgniteCliInterfaceTest.java b/modules/cli/src/test/java/org/apache/ignite/cli/deprecated/IgniteCliInterfaceTest.java
index 218b0c865..377ff7c98 100644
--- a/modules/cli/src/test/java/org/apache/ignite/cli/deprecated/IgniteCliInterfaceTest.java
+++ b/modules/cli/src/test/java/org/apache/ignite/cli/deprecated/IgniteCliInterfaceTest.java
@@ -405,7 +405,7 @@ public class IgniteCliInterfaceTest extends AbstractCliTest {
     @DisplayName("cluster")
     class Cluster {
         @Test
-        @DisplayName("init --cluster-url http://localhost:10300 --meta-storage-node node1ConsistentId --meta-storage-node node2ConsistentId "
+        @DisplayName("init --cluster-endpoint-url http://localhost:10300 --meta-storage-node node1ConsistentId --meta-storage-node node2ConsistentId "
                 + "--cmg-node node2ConsistentId --cmg-node node3ConsistentId --cluster-name cluster")
         void initSuccess() {
             var expectedSentContent = "{\"metaStorageNodes\":[\"node1ConsistentId\",\"node2ConsistentId\"],"
@@ -424,7 +424,7 @@ public class IgniteCliInterfaceTest extends AbstractCliTest {
 
             int exitCode = cmd(ctx).execute(
                     "cluster", "init",
-                    "--cluster-url", mockUrl,
+                    "--cluster-endpoint-url", mockUrl,
                     "--meta-storage-node", "node1ConsistentId",
                     "--meta-storage-node", "node2ConsistentId",
                     "--cmg-node", "node2ConsistentId",
@@ -452,7 +452,7 @@ public class IgniteCliInterfaceTest extends AbstractCliTest {
 
             int exitCode = cmd(ctx).execute(
                     "cluster", "init",
-                    "--cluster-url", mockUrl,
+                    "--cluster-endpoint-url", mockUrl,
                     "--meta-storage-node", "node1ConsistentId",
                     "--meta-storage-node", "node2ConsistentId",
                     "--cmg-node", "node2ConsistentId",
@@ -467,11 +467,11 @@ public class IgniteCliInterfaceTest extends AbstractCliTest {
         }
 
         @Test
-        @DisplayName("init --cluster-url http://localhost:10300 --cmg-node node2ConsistentId --cmg-node node3ConsistentId")
+        @DisplayName("init --cluster-endpoint-url http://localhost:10300 --cmg-node node2ConsistentId --cmg-node node3ConsistentId")
         void metastorageNodesAreMandatoryForInit() {
             int exitCode = cmd(ctx).execute(
                     "cluster", "init",
-                    "--cluster-url", mockUrl,
+                    "--cluster-endpoint-url", mockUrl,
                     "--cmg-node", "node2ConsistentId",
                     "--cmg-node", "node3ConsistentId",
                     "--cluster-name", "cluster"
@@ -484,7 +484,7 @@ public class IgniteCliInterfaceTest extends AbstractCliTest {
         }
 
         @Test
-        @DisplayName("init --cluster-url http://localhost:10300 --meta-storage-node node2ConsistentId --meta-storage-node node3ConsistentId")
+        @DisplayName("init --cluster-endpoint-url http://localhost:10300 --meta-storage-node node2ConsistentId --meta-storage-node node3ConsistentId")
         void cmgNodesAreNotMandatoryForInit() {
             clientAndServer
                     .when(request()
@@ -495,7 +495,7 @@ public class IgniteCliInterfaceTest extends AbstractCliTest {
 
             int exitCode = cmd(ctx).execute(
                     "cluster", "init",
-                    "--cluster-url", mockUrl,
+                    "--cluster-endpoint-url", mockUrl,
                     "--meta-storage-node", "node1ConsistentId",
                     "--meta-storage-node", "node2ConsistentId",
                     "--cluster-name", "cluster"
@@ -508,11 +508,11 @@ public class IgniteCliInterfaceTest extends AbstractCliTest {
         }
 
         @Test
-        @DisplayName("init --cluster-url http://localhost:10300 --meta-storage-node node1ConsistentId --cmg-node node2ConsistentId")
+        @DisplayName("init --cluster-endpoint-url http://localhost:10300 --meta-storage-node node1ConsistentId --cmg-node node2ConsistentId")
         void clusterNameIsMandatoryForInit() {
             int exitCode = cmd(ctx).execute(
                     "cluster", "init",
-                    "--cluster-url", mockUrl,
+                    "--cluster-endpoint-url", mockUrl,
                     "--meta-storage-node", "node1ConsistentId",
                     "--cmg-node", "node2ConsistentId"
             );
@@ -527,7 +527,7 @@ public class IgniteCliInterfaceTest extends AbstractCliTest {
         @DisplayName("config")
         class Config {
             @Test
-            @DisplayName("show --cluster-url http://localhost:10300")
+            @DisplayName("show --cluster-endpoint-url http://localhost:10300")
             void show() {
                 clientAndServer
                         .when(request()
@@ -536,7 +536,7 @@ public class IgniteCliInterfaceTest extends AbstractCliTest {
                         )
                         .respond(response("{\"autoAdjust\":{\"enabled\":true}}"));
 
-                int exitCode = execute("cluster config show --cluster-url " + mockUrl);
+                int exitCode = execute("cluster config show --cluster-endpoint-url " + mockUrl);
 
                 assertThatExitCodeMeansSuccess(exitCode);
 
@@ -549,7 +549,7 @@ public class IgniteCliInterfaceTest extends AbstractCliTest {
             }
 
             @Test
-            @DisplayName("show --cluster-url http://localhost:10300 --selector local.baseline")
+            @DisplayName("show --cluster-endpoint-url http://localhost:10300 --selector local.baseline")
             void showSubtree() {
                 clientAndServer
                         .when(request()
@@ -558,7 +558,7 @@ public class IgniteCliInterfaceTest extends AbstractCliTest {
                         )
                         .respond(response("{\"autoAdjust\":{\"enabled\":true}}"));
 
-                int exitCode = execute("cluster config show --cluster-url " + mockUrl + " --selector local.baseline");
+                int exitCode = execute("cluster config show --cluster-endpoint-url " + mockUrl + " --selector local.baseline");
 
                 assertThatExitCodeMeansSuccess(exitCode);
 
@@ -571,7 +571,7 @@ public class IgniteCliInterfaceTest extends AbstractCliTest {
             }
 
             @Test
-            @DisplayName("update --cluster-url http://localhost:10300 local.baseline.autoAdjust.enabled=true")
+            @DisplayName("update --cluster-endpoint-url http://localhost:10300 local.baseline.autoAdjust.enabled=true")
             void updateHocon() {
                 clientAndServer
                         .when(request()
@@ -581,7 +581,8 @@ public class IgniteCliInterfaceTest extends AbstractCliTest {
                         )
                         .respond(response(null));
 
-                int exitCode = execute("cluster config update --cluster-url " + mockUrl + " local.baseline.autoAdjust.enabled=true");
+                int exitCode = execute("cluster config update --cluster-endpoint-url "
+                        + mockUrl + " local.baseline.autoAdjust.enabled=true");
 
                 assertThatExitCodeMeansSuccess(exitCode);
 
diff --git a/modules/cli/src/test/resources/integration_tests.ini b/modules/cli/src/test/resources/integration_tests.ini
index 6031a5f31..a460179a0 100644
--- a/modules/cli/src/test/resources/integration_tests.ini
+++ b/modules/cli/src/test/resources/integration_tests.ini
@@ -2,5 +2,5 @@
 current_profile = default
 
 [default]
-ignite.cluster-url = http://localhost:10300
+ignite.cluster-endpoint-url = http://localhost:10300
 ignite.jdbc-url = jdbc:ignite:thin://127.0.0.1:10800
diff --git a/modules/cli/src/test/java/org/apache/ignite/cli/core/repl/completer/DynamicCompleterFilterTest.java b/modules/cli/src/test/java/org/apache/ignite/cli/core/repl/completer/DynamicCompleterFilterTest.java
index a75d7f24c..01692b194 100644
--- a/modules/cli/src/test/java/org/apache/ignite/cli/core/repl/completer/DynamicCompleterFilterTest.java
+++ b/modules/cli/src/test/java/org/apache/ignite/cli/core/repl/completer/DynamicCompleterFilterTest.java
@@ -31,7 +31,7 @@ class DynamicCompleterFilterTest {
         // Given
         String[] words = new String[]{"cluster", "config", "show", ""};
         // And completion candidates
-        String[] candidates = new String[]{"--selector", "--cluster-url", "--help", "-h"};
+        String[] candidates = new String[]{"--selector", "--cluster-endpoint-url", "--help", "-h"};
         // And user is not connected to the cluster
         Session session = notConnected();
 
@@ -39,7 +39,7 @@ class DynamicCompleterFilterTest {
         String[] filtered = new DynamicCompleterFilter(session).filter(words, candidates);
 
         // Then help is filtered out
-        assertThat(asList(filtered), containsInAnyOrder("--selector", "--cluster-url"));
+        assertThat(asList(filtered), containsInAnyOrder("--selector", "--cluster-endpoint-url"));
     }
 
     private static Session notConnected() {
@@ -59,7 +59,7 @@ class DynamicCompleterFilterTest {
         // Given typed words that end with "-"
         String[] words = new String[]{"cluster", "config", "show", "-"};
         // And completion candidates
-        String[] candidates = new String[]{"--selector", "--cluster-url", "--help", "-h"};
+        String[] candidates = new String[]{"--selector", "--cluster-endpoint-url", "--help", "-h"};
         // And user is not connected to the cluster
         Session session = notConnected();
 
@@ -67,7 +67,7 @@ class DynamicCompleterFilterTest {
         String[] filtered = new DynamicCompleterFilter(session).filter(words, candidates);
 
         // Then help is NOT filtered out
-        assertThat(asList(filtered), containsInAnyOrder("--selector", "--cluster-url", "--help", "-h"));
+        assertThat(asList(filtered), containsInAnyOrder("--selector", "--cluster-endpoint-url", "--help", "-h"));
     }
 
     @Test
@@ -75,14 +75,14 @@ class DynamicCompleterFilterTest {
         // Given typed words that end with "-"
         String[] words = new String[]{"cluster", "config", "show", ""};
         // And completion candidates
-        String[] candidates = new String[]{"--selector", "--cluster-url", "--help", "-h"};
+        String[] candidates = new String[]{"--selector", "--cluster-endpoint-url", "--help", "-h"};
         // And
         Session session = connected();
 
         // When
         String[] filtered = new DynamicCompleterFilter(session).filter(words, candidates);
 
         // Then cluster-url and help are filtered out
         assertThat(asList(filtered), containsInAnyOrder("--selector"));
     }
 
@@ -91,7 +91,7 @@ class DynamicCompleterFilterTest {
         // Given typed words that end with "-"
         String[] words = new String[]{"cluster", "config", "show", "-"};
         // And completion candidates
-        String[] candidates = new String[]{"--selector", "--cluster-url", "--help", "-h"};
+        String[] candidates = new String[]{"--selector", "--cluster-endpoint-url", "--help", "-h"};
         // And
         Session session = connected();
 
@@ -99,6 +99,6 @@ class DynamicCompleterFilterTest {
         String[] filtered = new DynamicCompleterFilter(session).filter(words, candidates);
 
         // Then help is NOT filtered out
-        assertThat(asList(filtered), containsInAnyOrder("--selector", "--cluster-url", "--help", "-h"));
+        assertThat(asList(filtered), containsInAnyOrder("--selector", "--cluster-endpoint-url", "--help", "-h"));
     }
 }
@@ -75,14 +75,14 @@ class DynamicCompleterFilterTest {
         String[] filtered = new DynamicCompleterFilter(session).filter(words, candidates);
 
-        // Then cluster-url and help are filtered out
+        // Then cluster-endpoint-url and help are filtered out
         assertThat(asList(filtered), containsInAnyOrder("--selector"));
     }
diff --git a/modules/cli/src/test/java/org/apache/ignite/cli/core/repl/completer/HoconDynamicCompleterTest.java b/modules/cli/src/test/java/org/apache/ignite/cli/core/repl/completer/HoconDynamicCompleterTest.java
index c96170a4c..62a872909 100644
--- a/modules/cli/src/test/java/org/apache/ignite/cli/core/repl/completer/HoconDynamicCompleterTest.java
+++ b/modules/cli/src/test/java/org/apache/ignite/cli/core/repl/completer/HoconDynamicCompleterTest.java
@@ -129,8 +129,8 @@ class HoconDynamicCompleterTest {
     void doesNotCompletesIfLastWordIsClusterUrl() {
         // Given
         completer = completerFrom("root: { subRoot: value }");
-        // And --cluster-url is the last typed word
-        String[] typedWords = {"cluster", "config", "show", "--cluster-url"};
+        // And --cluster-endpoint-url is the last typed word
+        String[] typedWords = {"cluster", "config", "show", "--cluster-endpoint-url"};
 
         // When
         List<String> completions = completer.complete(typedWords);
@@ -143,8 +143,8 @@ class HoconDynamicCompleterTest {
     void doesNotCompletesIfLastWordIsClusterUrlAndEmptyString() {
         // Given
         completer = completerFrom("root: { subRoot: value }");
-        // And --cluster-url is the last typed word
-        String[] typedWords = {"cluster", "config", "show", "--cluster-url", ""};
+        // And --cluster-endpoint-url is the last typed word
+        String[] typedWords = {"cluster", "config", "show", "--cluster-endpoint-url", ""};
 
         // When
         List<String> completions = completer.complete(typedWords);